@@ -1,8 +1,9 @@
 /*
  * ean.c -- encoding for ean, upc and isbn
  *
- * Copyright (c) 1999 Alessandro Rubini (rubini@gnu.org)
- * Copyright (c) 1999 Prosa Srl. (prosa@prosa.it)
+ * Copyright (c) 1999 Alessandro Rubini <rubini@gnu.org>
+ * Copyright (c) 1999 Prosa Srl. <prosa@prosa.it>
+ * Copyright (c) 2001 Boszormenyi Zoltan <zboszor@mail.externet.hu>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -379,7 +380,7 @@ int Barcode_isbn_verify(unsigned char *text)
 {
     int i, ndigit=0;
 
-    for (i=0; i < strlen(text); i++) {
+    for (i=0; text[i]; i++) {
 	if (text[i] == '-')
 	    continue;
 	if (isdigit(text[i])) {
